diff --git a/RFC/skeletons/ini.xml b/RFC/skeletons/ini.xml
index 9d7a1dce8..354375dcd 100644
--- a/RFC/skeletons/ini.xml
+++ b/RFC/skeletons/ini.xml
@@ -21,13 +21,13 @@
theini_option
itsvalue
- its PHP_INI_* value
+ its INI_* value
version changes information
anotherini_option
itsvalue
- its PHP_INI_* value
+ its INI_* value
@@ -37,9 +37,9 @@
&ini.php.constants;
-
+
&ini.descriptions.title;
-
+
diff --git a/scripts/docgen/docgen.php b/scripts/docgen/docgen.php
index 17e914ced..5fb54ec26 100644
--- a/scripts/docgen/docgen.php
+++ b/scripts/docgen/docgen.php
@@ -678,10 +678,10 @@ function gen_extension_markup(ReflectionExtension $obj, $content, $xml_file) { /
if ($ini = ini_get_all($obj->name)) {
$visibility = array(
- INI_USER => 'PHP_INI_USER',
- INI_PERDIR => 'PHP_INI_PERDIR',
- INI_SYSTEM => 'PHP_INI_SYSTEM',
- INI_ALL => 'PHP_INI_ALL',
+ INI_USER => 'INI_USER',
+ INI_PERDIR => 'INI_PERDIR',
+ INI_SYSTEM => 'INI_SYSTEM',
+ INI_ALL => 'INI_ALL',
);
$ident = get_ident_size('INI_ENTRIES', $content);
diff --git a/scripts/genPHP_INI_ENTRY.php b/scripts/genPHP_INI_ENTRY.php
index 424338739..c5fb33d00 100644
--- a/scripts/genPHP_INI_ENTRY.php
+++ b/scripts/genPHP_INI_ENTRY.php
@@ -67,9 +67,9 @@
$legend = <<
@@ -83,23 +83,23 @@
- PHP_INI_USER
+ INI_USER
1
Entry can be set in user scripts
- PHP_INI_PERDIR
+ INI_PERDIR
2
Entry can be set in .htaccess
- PHP_INI_SYSTEM
+ INI_SYSTEM
4
Entry can be set in php.ini or
httpd.conf
- PHP_INI_ALL
+ INI_ALL
7
Entry can be set anywhere
@@ -192,7 +192,7 @@ function findINI($fname) {/*{{{*/
continue;
}
$found['INI'][$entry[1]] = array(
- 'def' => $entry[2],
+ 'def' => $entry[2],
'mod' => str_replace(array(' ', "\n","\r","\t"),'',$entry[3])
);
}
@@ -218,7 +218,7 @@ function flatentree($tree, $section) {/*{{{*/
function createINI($dir, $cfgs) {/*{{{*/
global $master_ini_table;
-
+
if (empty($cfgs)) {
return false;
}
@@ -252,7 +252,7 @@ function createINI($dir, $cfgs) {/*{{{*/
$rows .= " \n";
}
$master_ini_table .= $rows;
-
+
if ($dir == 'en/chapters') {
$id = 'general';
} else {
@@ -284,7 +284,7 @@ function createMasterINI ($dir, $rows) {/*{{{*/
fflush($fp);
fclose($fp);
echo "CREATED {$GLOBALS['phpdoc_dir']}/{$dir}/config.master_test.xml\n";
- }
+ }
} /*}}}*/
// Set the PHP4 and the PHPDOC source dirs
diff --git a/scripts/mk_ini_set_table.sh b/scripts/mk_ini_set_table.sh
index d7f1e5f32..8d82bb2a5 100755
--- a/scripts/mk_ini_set_table.sh
+++ b/scripts/mk_ini_set_table.sh
@@ -6,18 +6,18 @@
# Author: Jesus M. Castagnetto
# Created: Mon Mar 19 04:57:02 PST 2001
# Updated: Thu Apr 25 11:42:26 PDT 2002
# - look through all PHP_INI_ containing files
# - save table in the new split dir for the function
# Updated: Wed Nov 20 18:16:12 PST 2002
-# - rearrange the order of the tables, put the PHP_INI_* definitions first.
+# - rearrange the order of the tables, put the INI_* definitions first.
-cfiles=`grep -rl PHP_INI_ ../php4/*`
+cfiles=`grep -rl INI_ ../php4/*`
ini_set_table="en/reference/info/functions/ini_set_table";
awk 'BEGIN {
print "";
print " ";
- print " The PHP_INI_* constants used in the table below are defined as follows:";
+ print " The INI_* constants used in the table below are defined as follows:";
print " ";
print " ";
print " ";
@@ -28,23 +28,23 @@ awk 'BEGIN {
print "
";
print " ";
print " ";
- print " PHP_INI_USER";
+ print " INI_USER";
print " 1";
print " Entry can be set in user scripts";
print "
";
print " ";
- print " PHP_INI_PERDIR";
+ print " INI_PERDIR";
print " 2";
print " Entry can be set in .htaccess";
print "
";
print " ";
- print " PHP_INI_SYSTEM";
+ print " INI_SYSTEM";
print " 4";
print " Entry can be set in php.ini or";
print " httpd.conf";
print "
";
print " ";
- print " PHP_INI_ALL";
+ print " INI_ALL";
print " 7";
print " Entry can be set anywhere";
print "
";
@@ -63,7 +63,7 @@ awk 'BEGIN {
print " ";
print " ";
}
-$0 ~ /PHP_INI_.*\(/ && $0 !~ /^static/ && $0 !~ /PHP_INI_(BEGIN|END)/ {
+$0 ~ /INI_.*\(/ && $0 !~ /^static/ && $0 !~ /INI_(BEGIN|END)/ {
nf = split($0,tmp,",");
varname = substr(tmp[1], index(tmp[1], "\""));
@@ -6,18 +6,18 @@
# Created: Mon Mar 19 04:57:02 PST 2001
# Updated: Thu Apr 25 11:42:26 PDT 2002
-# - look through all PHP_INI_ containing files
+# - look through all INI_ containing files
# - save table in the new split dir for the function
# Updated: Wed Nov 20 18:16:12 PST 2002